import { a } from "x";
import b from "y";
const d = null;
const obj = (a, b);
